package de.intevation.flys.artifacts.access;

import java.util.Date;
import java.util.LinkedList;
import java.util.List;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.model.DateRange;


public class BedQualityAccess extends Access {

    private Double from;
    private Double to;
    private String river;
    private List<DateRange> ranges;

    public BedQualityAccess(FLYSArtifact artifact) {
        super(artifact);
    }

    public double getFrom() {
        if (from == null) {
            from = getDouble("ld_from");
        }
        return from.doubleValue();
    }

    public double getTo() {
        if (to == null) {
            to = getDouble("ld_to");
        }
        return to.doubleValue();
    }

    public String getRiver() {
        if (river == null) {
            river = getString("river");
        }
        return river;
    }

    public List<DateRange> getDateRanges() {
        if (ranges == null) {
            ranges = extractRanges(getString("periods"));
        }
        return ranges;
    }

    private List<DateRange> extractRanges(String dateString) {
        List<DateRange> list = new LinkedList<DateRange>();
        String[] dates = dateString.split(";");
        for (String s : dates) {
            String[] pair = s.split(",");
            try {
                long l1      = Long.parseLong(pair[0]);
                long l2      = Long.parseLong(pair[1]);
                Date first   = new Date(l1);
                Date second  = new Date(l2);
                DateRange dr = new DateRange(first, second);
                list.add(dr);
            }
            catch (NumberFormatException nfe) {
                continue;
            }
        }
        return list;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :